/*
 * gen_dataset.c	SPAMNET Network Tester Dataset Generator
 *
 * Copyright 2003 MontaVista Software
 *
 * Author: Steven Dake (sdake@mvista.com)
 *
 * This program is licensed under the MontaVista Software, Inc. License
 * Agreement ("License Agreement"), and is for the purposes of the License
 * Agreement a MontaVista Licensed Deployment Program.  The License requires
 * that you have a valid Product Subscription and Software License Agreement
 * with MontaVista Software, Inc., or are a Named Contact with active access to
 * the MontaVista Zone, or have a Software License Agreement with MontaVista
 * Software, Inc.  This program comes with no warranties other than those
 * provided for in the Product Subscription agreement.  The License Agreement
 * grants you the right to install, modify, and use the program.  You may
 * distribute the object code and scripts for this program, but you have no
 * right to distribute source code for this program.
 */
#include <stdio.h>
#include <stdlib.h>

/*
 * Change these data to have a different dataset
 *
 * Please NOTE both client and server must use the dataset
 * or the comparisons of data will fail and the test will
 * not be useful.
 */
#define DATASETS 255
#define MINDATAINSET	32
#define MAXDATAINSET 8192

int main (void)
{
	int datainset = 0;
	int i;
	int j;
	FILE *implementation;
	FILE *interface;

	implementation = fopen ("dataset.c", "w");
	interface = fopen ("dataset.h", "w");

	/*
	 * Output all data sets
	 */
	fprintf (interface, "#define DATASETS %d\n\n", DATASETS);
	fprintf (implementation, "#include \"dataset.h\"\n\n");
	for (i = 0; i < DATASETS; i++) {
		datainset = (random() % (MAXDATAINSET - MINDATAINSET)) + MINDATAINSET;

		fprintf (implementation, "#define DATAINSET%d %d\n", i, datainset);
		fprintf (implementation, "char data%d[] = {\n\t", i);
		for (j = 0; j < datainset; j++) {
			fprintf (implementation, "0x%x, ", (int) (random() % 256));
			if ((j % 10) == 9) {
				fprintf (implementation, "\n\t");
			}
		}
		fprintf (implementation, "};\n\n");
	}
	fprintf (interface, "struct dataset {\n");
	fprintf (interface, "\tint size;\n");
	fprintf (interface, "\tchar *dataset;\n");
	fprintf (interface, "};\n\n");
	fprintf (interface, "extern struct dataset datasets[];\n\n");

	fprintf (implementation, "struct dataset datasets[] = {\n\t");
	for (i = 0; i < DATASETS; i++) {
		fprintf (implementation, "{ DATAINSET%d, data%d }, ", i, i);
		if ((i % 2) == 1) {
			fprintf (implementation, "\n");
			if ((i + 1) != DATASETS) {
				fprintf (implementation, "\t");
			}
		}
	}
	fprintf (implementation, "};\n");
	fclose (interface);
	fclose (implementation);

	return (0);
}

